@@ -243,7 +243,14 @@ Tthread_manager_base::Tthread_manager_base()
 				physical_cores = get_CPU_info_from_os("core id");
 				logical_processors = get_CPU_info_from_os("processor"); 
 
-				if ((physical_cores.size() == 0) or (logical_processors.size() == 0))
+	// 				Some versions of Linux do not have core_id entry. Raspian is such a case!
+	// 				For such versions we set the physical cores equal to the logical_processors
+	// 				and hope that everything worls fine.
+				
+				if ((physical_cores.size() == 0) and (logical_processors.size() > 0))
+					physical_cores = logical_processors;
+
+				if ((physical_cores.size() == 0) and (logical_processors.size() == 0))
 				{
 					flush_warn(WARN_ALL, "Could not read CPU information from OS. Continuing with 1 thread.");
 					number_of_logical_processors = 1;
@@ -310,6 +317,7 @@ void Tthread_manager_base::reserve_threads(Tparallel_control parallel_ctrl)
 			GPUs = 0;
 		GPU_number_offset = parallel_ctrl.GPU_number_offset;
 	#endif
+	keep_GPU_alive_after_disconnection = parallel_ctrl.keep_GPU_alive_after_disconnection;
 		
 	position = find(list_of_thread_managers, this);
 	if (position.size() == 0)
@@ -380,8 +388,11 @@ void Tthread_manager_base::connect_to_GPU()
 void Tthread_manager_base::disconnect_from_GPU()
 {
 	#ifdef  COMPILE_WITH_CUDA__
-		if (connected_to_GPU == true)
+		if ((keep_GPU_alive_after_disconnection == false) and (connected_to_GPU == true))
+		{
 			cudaThreadExit();
+			flush_info(INFO_2, "\nThread %d cleared GPU.", thread_id);
+		}
 		connected_to_GPU = false;
 	#endif
 }
@@ -508,10 +519,10 @@ vector <unsigned> Tthread_manager_base::get_CPU_info_from_os(const char* entry)
 
 	#if defined(POSIX_OS__) && !defined(__MINGW32__)
 		int i;
-		char c;
+		int c;
 		FILE* fp;
 		int io_return;
-		char command[128];
+		char command[256];
 
 		#ifdef __MACH__
 			strcpy(command, "sysctl -a | grep machdep.cpu | grep '");
